@@ -85,12 +85,12 @@ void XYChartBackgroundPainter::updateLinePolygons()
     m_linePolygons.clear();
 
     Dimension* xAxis = m_xyChartCore->xAxis();
-    QList<Dimension*> dimensions = m_xyChartCore->dimensionsList();
+    const QList<Dimension*> dimensions = m_xyChartCore->dimensionsList();
     QAbstractTableModel* model = m_xyChartCore->model();
 
     const int xAxisColumn = xAxis->dataColumn();
 
-    foreach(Dimension* dimension, dimensions)
+    for (Dimension* dimension : dimensions)
     {
         const int column = dimension->dataColumn();
         QPolygonF line;
@@ -110,3 +110,5 @@ void XYChartBackgroundPainter::updateLinePolygons()
 
     emit linePolygonsUpdated();
 }
+
+#include "moc_xychartbackgroundpainter.cpp"
\ No newline at end of file
